@@ -16,6 +16,8 @@ from subprocess import call
 from django.conf import settings
 from django.template import Context, Template
 
+from inkpy.utils import switch_language
+
 
 class Error(Exception):
     pass
@@ -43,9 +45,11 @@ class Converter(object):
     :param source_file: The source odt file path.
     :param output_path: The destination pdf file path.
     :param data: The directory with data to fill template.
+    :param lang_code: forces language during docs generation, if None then
+        django's *settings.LANGUAGE_CODE* is used.
     """
 
-    def __init__(self, source_file, output_path, data):
+    def __init__(self, source_file, output_path, data, lang_code=None):
         if not os.path.exists(source_file):
             raise FileDoesNotExist()
         self.source_file = source_file
@@ -60,6 +64,12 @@ class Converter(object):
         self.data = data
         self.tmp_dir_master = settings.INKPY.get('tmp_dir', '/tmp/INKPY')
         self.tmp_dir = "{}/{}".format(self.tmp_dir_master, self.data['id'])
+        self.set_lang(lang_code)
+
+    def set_lang(self, lang_code):
+        if not lang_code:
+            lang_code = getattr(settings, 'LANGUAGE_CODE').split('-')[0]
+        self.lang_code = lang_code
 
     def convert(self):
         self._convert()
@@ -112,7 +122,9 @@ class Converter(object):
     def _django_renderer(self, file_content):
         template = Template(file_content)
         context = Context(self.data)
-        return template.render(context)
+        with switch_language(self.lang_code):
+            rendered = template.render(context)
+        return rendered
 
     def zip_dir(self, dirPath=None, zipFilePath=None, includeDirInZip=True):
         """Create a zip archive from a directory.
@@ -144,8 +156,10 @@ class Converter(object):
         if not zipFilePath:
             zipFilePath = dirPath + ".zip"
         if not os.path.isdir(dirPath):
-            raise OSError("dirPath argument must point to a directory. "
-                "'%s' does not." % dirPath)
+            raise OSError(
+                "dirPath argument must point to a directory. "
+                "'%s' does not." % dirPath
+            )
         parentDir, dirToZip = os.path.split(dirPath)
 
         def trimPath(path):
@@ -154,7 +168,9 @@ class Converter(object):
             if parentDir:
                 archivePath = archivePath.replace(os.path.sep, "", 1)
             if not includeDirInZip:
-                archivePath = archivePath.replace(dirToZip + os.path.sep, "", 1)
+                archivePath = archivePath.replace(
+                    dirToZip + os.path.sep, "", 1,
+                )
             return os.path.normcase(archivePath)
 
         outFile = zipfile.ZipFile(
